@@ -12,6 +12,13 @@ class CubeBackend(abc.ABC):
         Takes a `CubeQuery` instance and returns the resulting records
         """
 
+    def get_one_record(self, query: CubeQuery) -> NamedTuple:
+        """
+        A convenience method for situations where only one record is returned by a query
+        (usually result of aggregation over the whole set)
+        """
+        return list(self.get_records(query))[0]
+
     @abc.abstractmethod
     def store_records(self, cube: Type[Cube], records: Iterable[NamedTuple]):
         """
