@@ -24,6 +24,7 @@ from hcube.api.models.filters import (
     IsNullFilter,
     ComparisonFilter,
     NegativeListFilter,
+    EqualityFilter,
 )
 from hcube.api.models.materialized_views import AggregatingMaterializedView
 from hcube.api.models.metrics import FloatMetric, Metric, IntMetric
@@ -139,6 +140,7 @@ class ClickhouseCubeBackend(CubeBackend):
 
         The query must not contain any aggregations or group_bys - just filter and limit + ordering
         """
+        self.create_table(query.cube)  # ensure the table exists
         # check that the query can be used
         if query.aggregations or query.groups or query.transforms:
             raise ConfigurationError(
@@ -271,6 +273,8 @@ class ClickhouseCubeBackend(CubeBackend):
             return f"{fltr.dimension.name} IS{modifier} NULL", {}
         if isinstance(fltr, ComparisonFilter):
             return f"{fltr.dimension.name} {fltr.comparison.value} %({key})s", {key: fltr.value}
+        if isinstance(fltr, EqualityFilter):
+            return f"{fltr.dimension.name} = %({key})s", {key: fltr.value}
         raise ValueError(f"unsupported filter {fltr.__class__}")
 
     def _agg_name(self, agg: AggregationOp):
